@@ -17,7 +17,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '1.8.11';
+    $VERSION = '2.0.0';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -111,6 +111,23 @@ sub _pre_184 {
     return;
 }
 
+sub _pre_200 {
+    my ( $version, $SETTING ) = @_;
+    if ( version->parse($version) < version->parse('2.0.0') ) {
+        if ( defined $SETTING->{selection}
+            and ref( $SETTING->{selection} ) eq 'ARRAY' )
+        {
+            my %selection;
+            my $i = 0;
+            for my $key (qw(x y width height)) {
+                $selection{$key} = $SETTING->{selection}[ $i++ ];
+            }
+            $SETTING->{selection} = \%selection;
+        }
+    }
+    return;
+}
+
 sub read_config {
     my ( $filename, $logger ) = @_;
     my ( %SETTING, $conf );
@@ -182,6 +199,8 @@ sub read_config {
 
     _pre_184( $version, \%SETTING );
 
+    _pre_200( $version, \%SETTING );
+
     $logger->debug( Dumper( \%SETTING ) );
     return %SETTING;
 }
