@@ -34,7 +34,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '1.8.11';
+    $VERSION = '2.0.0';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -129,7 +129,9 @@ sub clone {
         if ( $self->{filename} =~ /([.]\w*)$/xsm ) { $suffix = $1 }
         $new->{filename} =
           File::Temp->new( DIR => $self->{dir}, SUFFIX => $suffix );
-        $logger->info("Cloning $self->{filename} -> $new->{filename}");
+        $logger->info(
+"Cloning $self->{filename} ($self->{uuid}) -> $new->{filename} ($new->{uuid})"
+        );
 
         # stringify filename to prevent copy from mangling it
         copy( "$self->{filename}", "$new->{filename}" )
